#include "mainwindow.h"

Image_Type::Image_Type(QWidget *parent) :
    QComboBox(parent),
    m_ImageTypeSetting_Dialog(nullptr)
{
    changed = false;
}

void Image_Type::initialize(){
    changed = true;
}

void Image_Type::update_ui(INT_SETTING_VALUE image_type_para){

    if(changed == true){
        this->clear();
        if(image_type_para.capability.supportLevel == kSDISupportLevelAvailable){
            this->set_enabled(true);
            this->add_item(image_type_para.capability.list, image_type_para.capability.countOfList);
            this->select_item(image_type_para);
        }else {
            this->set_enabled(false);
        }
        changed = false;
    }
}

void Image_Type::set_enabled(bool enabled){

    if(enabled == true){
        this->setEnabled(true);
    }else {
        this->setEnabled(false);
    }
}

void Image_Type::add_item(int32_t item_list[], int32_t list_size){

    int i = 0;
    while(i < list_size){
        if(item_list[i] == ColorTypeAuto){
            this->insertItem(i, TranslationString::GetString().translation_str.MAINSETTING_017, ColorTypeAuto);
        }else if(item_list[i] == ColorTypeRGB24){ //ColorType
            this->insertItem(i, TranslationString::GetString().translation_str.MAINSETTING_014, ColorTypeRGB24);
        }else if(item_list[i] == ColorTypeMono8){
            this->insertItem(i, TranslationString::GetString().translation_str.MAINSETTING_015, ColorTypeMono8);
        }else if(item_list[i] == ColorTypeMono1){
            this->insertItem(i, TranslationString::GetString().translation_str.MAINSETTING_016, ColorTypeMono1);
        }else if(item_list[i] == ColorTypeRGB48){ // not supported
            this->insertItem(i, "Color (48 bit)", ColorTypeRGB48);
        }else if(item_list[i] == ColorTypeMono16){ // not supported
            this->insertItem(i, "Grayscale (16 bit)", ColorTypeMono16);
        }
        i++;
    }

    //イメージタイプ自動の設定を追加する
    if(1){//TBD
        this->insertItem(i, TranslationString::GetString().translation_str.CONFIG_DOC_010, ColorTypeSettings);
        this->insertSeparator(i);
    }
}

void Image_Type::select_item(INT_SETTING_VALUE image_type_para){

    int list_size = image_type_para.capability.countOfList;

    int i = 0;
    while(i < list_size){
        if(image_type_para.capability.list[i] == image_type_para.select){
            this->setCurrentIndex(i);
        }
        i++;
    }
}

void Image_Type::item_event(int value, Supervisor* sv)
{
    QVariant select_item = this->itemData(value);

    if(select_item == ColorTypeAuto){
        sv->device_data.ColorType.select = ColorTypeAuto;
    }else if(select_item == ColorTypeRGB24){
        sv->device_data.ColorType.select = ColorTypeRGB24;
    }else if(select_item == ColorTypeMono8){
        sv->device_data.ColorType.select = ColorTypeMono8;
    }else if(select_item == ColorTypeMono1){
        sv->device_data.ColorType.select = ColorTypeMono1;
    }else if(select_item == ColorTypeRGB48){
        sv->device_data.ColorType.select = ColorTypeRGB48;
    }else if(select_item == ColorTypeMono16){
        sv->device_data.ColorType.select = ColorTypeMono16;
    }else if(select_item == ColorTypeSettings){
        this->item_event_options(sv);
    }
    changed = true;
}

void Image_Type::item_event_options(Supervisor* sv)
{
    //Initialize dialog
    if(!m_ImageTypeSetting_Dialog){
        m_ImageTypeSetting_Dialog = new ImageTypeSettingsDialog;
    }

    m_ImageTypeSetting_Dialog->Initialize(sv);

    if(m_ImageTypeSetting_Dialog->isHidden()){
        m_ImageTypeSetting_Dialog->exec();
    }else {
        m_ImageTypeSetting_Dialog->activateWindow();
    }

    sv->device_data.AutoColorPixelType.select = m_ImageTypeSetting_Dialog->get_currentItem();
    sv->device_data.AutoColorPixelLevel.select = m_ImageTypeSetting_Dialog->get_currentValue();
}
